@@ -3,11 +3,12 @@ from __future__ import annotations
 import shlex
 from abc import ABC
 from copy import deepcopy
-from typing import TYPE_CHECKING, Any, Awaitable, Callable, Dict, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Union
 
 from . import background_tasks, binding, globals
 from .elements.mixins.visibility import Visibility
 from .event_listener import EventListener
+from .events import handle_event
 from .slot import Slot
 
 if TYPE_CHECKING:
@@ -51,9 +52,17 @@ class Element(ABC, Visibility):
     def to_dict(self) -> Dict:
         events: Dict[str, Dict] = {}
         for listener in self._event_listeners:
+            words = listener.type.split('.')
+            type = words.pop(0)
+            specials = [w for w in words if w in {'capture', 'once', 'passive'}]
+            modifiers = [w for w in words if w in {'stop', 'prevent', 'self', 'ctrl', 'shift', 'alt', 'meta'}]
+            keys = [w for w in words if w not in specials + modifiers]
             events[listener.type] = {
-                'type': listener.type.split('.')[0],
-                'modifiers': listener.type.split('.')[1:],
+                'listener_type': listener.type,
+                'type': type,
+                'specials': specials,
+                'modifiers': modifiers,
+                'keys': keys,
                 'args': list(set(events.get(listener.type, {}).get('args', []) + listener.args)),
                 'throttle': min(events.get(listener.type, {}).get('throttle', float('inf')), listener.throttle),
             }
@@ -150,9 +159,7 @@ class Element(ABC, Visibility):
     def handle_event(self, msg: Dict) -> None:
         for listener in self._event_listeners:
             if listener.type == msg['type']:
-                result = listener.handler(msg)
-                if isinstance(result, Awaitable):
-                    background_tasks.create(result)
+                handle_event(listener.handler, msg, sender=self)
 
     def collect_descendant_ids(self) -> List[int]:
         '''includes own ID as first element'''
