@@ -1,7 +1,5 @@
 from typing import Any, Callable, Dict, List, Optional, Union
 
-import justpy as jp
-
 from .choice_element import ChoiceElement
 
 
@@ -15,12 +13,15 @@ class Select(ChoiceElement):
         :param value: the initial value
         :param on_change: callback to execute when selection changes
         """
-        view = jp.QSelect(options=options, label=label, input=self.handle_change, temp=False)
+        super().__init__(tag='q-select', options=options, value=value, on_change=on_change)
+        self._props['label'] = label
 
-        super().__init__(view, options, value=value, on_change=on_change)
+    def _msg_to_value(self, msg: Dict) -> Any:
+        return self._values[msg['args']['value']]
 
-    def value_to_view(self, value: Any):
+    def _value_to_model_value(self, value: Any) -> Any:
         try:
-            return self._labels[self._values.index(value)]
+            index = self._values.index(value)
+            return {'value': index, 'label': self._labels[index]}
         except ValueError:
-            return value
+            return None
