@@ -31,4 +31,4 @@ class Table(Element):
         self.run_method('update_grid')
 
     def call_api_method(self, name: str, *args) -> None:
-        self.run_method('call_api_method', name, args)
+        self.run_method('call_api_method', name, *args)
