@@ -2,10 +2,12 @@ import asyncio
 import functools
 import inspect
 from contextlib import nullcontext
-from typing import Any, Awaitable, Callable, Optional, Union
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Optional, Union
 
 from . import background_tasks, globals
-from .client import Client
+
+if TYPE_CHECKING:
+    from .client import Client
 
 
 def is_coroutine(object: Any) -> bool:
@@ -14,7 +16,7 @@ def is_coroutine(object: Any) -> bool:
     return asyncio.iscoroutinefunction(object)
 
 
-def safe_invoke(func: Union[Callable, Awaitable], client: Optional[Client] = None) -> None:
+def safe_invoke(func: Union[Callable, Awaitable], client: Optional['Client'] = None) -> None:
     try:
         if isinstance(func, Awaitable):
             async def func_with_client():
@@ -29,5 +31,5 @@ def safe_invoke(func: Union[Callable, Awaitable], client: Optional[Client] = Non
                     with client or nullcontext():
                         await result
                 background_tasks.create(result_with_client())
-    except:
+    except Exception:
         globals.log.exception(f'could not invoke {func}')
